@@ -17,7 +17,7 @@ use Getopt::Long;
 use VMware::vCloud;
 use strict;
 
-my $version = ( split ' ', '$Revision: 1.3 $' )[1];
+my $version = ( split ' ', '$Revision: 1.4 $' )[1];
 
 my ( $username, $password, $hostname, $orgname );
 
@@ -27,8 +27,8 @@ my $ret = GetOptions ( 'username=s' => \$username, 'password=s' => \$password,
 die "Check the POD. This script needs command line parameters." unless
  $username and $password and $hostname;
 
-my $vcd = new VMware::vCloud ( $hostname, $username, $password, $orgname, { debug => 1 } );
+my $vcd = new VMware::vCloud ( $hostname, $username, $password, $orgname, { debug => 3 } );
 
-my %vms = $vcd->list_vapps();
+my %vapps = $vcd->list_vapps();
 
-print "\n", Dumper(\%vms);
+print "\n", Dumper(\%vapps);
